//
//  ViewController.m
//  Map
//
//  Created by nyuguest on 4/19/13.
//  Copyright (c) 2013 nyuguest. All rights reserved.
//

#import "ViewController.h"
#import "Pin.h"

@interface ViewController ()
@end

@implementation ViewController

/*
- (id) initWithNibName: (NSString *) nibNameOrNil bundle: (NSBundle *) nibBundleOrNil
{
	self = [super initWithNibName: nibNameOrNil bundle: nibBundleOrNil];
	if (self) {
		// Custom initialization
	}
	return self;
}
*/

#pragma mark -
#pragma mark - View lifecycle

- (void) loadView
{
	CGRect frame = [UIScreen mainScreen].applicationFrame;
	MKMapView *mapView = [[MKMapView alloc] initWithFrame: frame];
	mapView.mapType = MKMapTypeHybrid;	//default is MKMapTypeStandard
	mapView.scrollEnabled = YES;		//default; let user drag
	mapView.zoomEnabled = YES;			//default; double tap, pinch, spread
	self.view = mapView;
}

- (void) viewDidLoad
{
	[super viewDidLoad];
	// Do any additional setup after loading the view.
	locationManager = [[CLLocationManager alloc] init];
	locationManager.desiredAccuracy = kCLLocationAccuracyBest; //default; uses power
	locationManager.delegate = self;
	[locationManager startUpdatingLocation];

	geocoder = [[CLGeocoder alloc] init];
}

- (void) didReceiveMemoryWarning
{
	[super didReceiveMemoryWarning];
	// Dispose of any resources that can be recreated.
}

#pragma mark -
#pragma mark Orientations

- (NSUInteger) supportedInterfaceOrientations {
	return UIInterfaceOrientationMaskAll;
}

- (BOOL) shouldAutorotate {
	return YES;
}

#pragma mark -
#pragma mark Protocol CLLocationManagerDelegate

- (void) locationManager: (CLLocationManager *) m
	didUpdateToLocation: (CLLocation *) newLocation
	fromLocation: (CLLocation *) oldLocation {

	if (m == locationManager) {
		[locationManager stopUpdatingLocation];

		NSLog(@"locationManager:didUpdateToLocation:fromLocation: Lat %.15g° Long %.15g°",
			newLocation.coordinate.latitude,
			newLocation.coordinate.longitude
		);

		/*
		 Create a region and put it into the MKMapView.
		 2nd argument is height of the region (north-south),
		 3rd argument is width of the region (east-west).
		 */
		CLLocationDistance meters = 100;	//east-west

		((MKMapView *)self.view).region = MKCoordinateRegionMakeWithDistance(
			newLocation.coordinate,
			meters * self.view.bounds.size.height / self.view.bounds.size.width,
			meters
		);

		[geocoder reverseGeocodeLocation: newLocation
			completionHandler: ^(NSArray *placemark, NSError *error) {
				if (placemark == nil) {
					NSLog(@"error == %@", error);
				} else {
					for (CLPlacemark *p in placemark) {
						NSLog(@"placemark == %@", p);
						CLLocationCoordinate2D c = newLocation.coordinate;

						//newline ignored
						NSString *subtitle = [NSString stringWithFormat: @"%g°%c %g°%c\n%@ %@",
							fabs(c.latitude),
							c.latitude >= 0 ? 'N' : 'S',
							fabs(c.longitude),
							c.longitude >= 0 ? 'E' : 'W',
							p.subThoroughfare, p.thoroughfare
						];

						Pin *pin = [[Pin alloc]
							initWithTitle: p.name
							subtitle: subtitle
							coordinate: c
						];

						[(MKMapView *)self.view addAnnotation: pin];
					}
				}
			}
		];
	}
}

- (void) locationManager: (CLLocationManager *) m
	didFailWithError: (NSError *) error {
	NSLog(@"locationManager:didFailWithError: %@", error);
}
@end
